pub fn apply_state_overrides<D>(
overrides: StateOverride,
cache_db: &mut CacheDB<D>,
) -> Result<(), BlockchainError>where
D: DatabaseRef<Error = DatabaseError>,Expand description
Applies the given state overrides to the given CacheDB
pub fn apply_state_overrides<D>(
overrides: StateOverride,
cache_db: &mut CacheDB<D>,
) -> Result<(), BlockchainError>where
D: DatabaseRef<Error = DatabaseError>,Applies the given state overrides to the given CacheDB